==> aria2_1.17.0.orig.tar.bz2: aria2-1.17.0/src/AppleMessageDigestImpl.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2013 Nils Maier
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_APPLE_MESSAGE_DIGEST_IMPL_H
#define D_APPLE_MESSAGE_DIGEST_IMPL_H

#include "common.h"

#include <string>

#include "SharedHandle.h"

namespace aria2 {

class MessageDigestImpl {
public:
  virtual ~MessageDigestImpl() {}
  static SharedHandle<MessageDigestImpl> sha1();
  static SharedHandle<MessageDigestImpl> create(const std::string& hashType);

  static bool supports(const std::string& hashType);
  static size_t getDigestLength(const std::string& hashType);

public:
  virtual size_t getDigestLength() const = 0;
  virtual void reset() = 0;
  virtual void update(const void* data, size_t length) = 0;
  virtual void digest(unsigned char* md) = 0;

protected:
  MessageDigestImpl() {}

private:
  MessageDigestImpl(const MessageDigestImpl&);
  MessageDigestImpl& operator=(const MessageDigestImpl&);

};

} // namespace aria2

#endif // D_APPLE_MESSAGE_DIGEST_IMPL_H

==> aria2-1.18.0.tar.bz2: aria2-1.18.0/src/AppleMessageDigestImpl.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2013 Nils Maier
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_APPLE_MESSAGE_DIGEST_IMPL_H
#define D_APPLE_MESSAGE_DIGEST_IMPL_H

#include "common.h"

#include <string>
#include <memory>

namespace aria2 {

class MessageDigestImpl {
public:
  virtual ~MessageDigestImpl() {}
  static std::unique_ptr<MessageDigestImpl> sha1();
  static std::unique_ptr<MessageDigestImpl> create(const std::string& hashType);

  static bool supports(const std::string& hashType);
  static size_t getDigestLength(const std::string& hashType);

public:
  virtual size_t getDigestLength() const = 0;
  virtual void reset() = 0;
  virtual void update(const void* data, size_t length) = 0;
  virtual void digest(unsigned char* md) = 0;

protected:
  MessageDigestImpl() {}

private:
  MessageDigestImpl(const MessageDigestImpl&);
  MessageDigestImpl& operator=(const MessageDigestImpl&);

};

} // namespace aria2

#endif // D_APPLE_MESSAGE_DIGEST_IMPL_H
